@@ -94,7 +94,7 @@
 #'be labelled. Should match the names of SNPs in the provided object
 #'\code{gdat}, otherwise nothing is done.
 #'@param color A range of colors to be used for drawing the heat map. Default
-#is \code{grey.colors(20)}.
+#'is \code{grey.colors(20)}.
 #'@param newpage If \code{TRUE} (default), the heat map will be drawn on a new page.
 #'@param name A character string specifying the name of the LDheatmap
 #'graphical object (\code{grob}) to be produced.
@@ -381,7 +381,7 @@
   #____________________________________________________________________________#
   ## Calculate or extract LDmatrix, then stored in LDMatrix as an upper triangular matrix
   
-  if(inherits(gdat,"SnpMatrix")){
+  if(inherits(gdat,"SnpMatrix")||inherits(gdat,"XSnpMatrix")){
     ## Exclude SNPs with less than 2 alleles:
     # NOT YET IMPLEMENTED for SnpMatrix, is implemented for data.frame, done in else structure below
     #gvars <- unlist(sapply(gdat, function(x) genetics::nallele(x) == 2))
